@@ -1,4 +1,5 @@
 from enum import Enum, unique
+from typing import Literal
 
 
 @unique
@@ -10,6 +11,9 @@ class Scoring(str, Enum):
     UNKNOWN = "unknown"
 
 
+ScoringLiteral = Literal["comstock", "virginia", "fixedTime", "chrono", "unknown"]
+
+
 @unique
 class Division(str, Enum):
     PCC = "pcc"
@@ -38,6 +42,9 @@ class PowerFactor(str, Enum):
     UNKNOWN = "unknown"
 
 
+PowerFactorLiteral = Literal["major", "minor", "unknown"]
+
+
 @unique
 class Classification(str, Enum):
     GM = "GM"
